==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/idresolver/AbstractResolver.java <==
/*
 * Copyright (c) 2009 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on 2010-01-25
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server.idresolver;

import org.apache.log4j.Logger;

import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.exceptions.AuthenticationException;
import pl.edu.icm.unicore.uvos.api.exceptions.IdentityNotKnownException;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.InvalidValueException;
import pl.edu.icm.unicore.uvos.engine.InternalAuthorization;
import pl.edu.icm.unicore.uvos.engine.SecurityContext;

public abstract class AbstractResolver implements IResolver
{
	private static final Logger log = Logger.getLogger(AbstractResolver.class);
	
	protected InternalAuthorization voAuthz;

	public AbstractResolver(InternalAuthorization voAuthz)
	{
		this.voAuthz = voAuthz;
	}

	protected SecurityContext authenticate(Identity r, String name) 
		throws IdUnresolvedException, InternalException, InvalidValueException
	{
		if (log.isTraceEnabled())
			log.trace("Trying to authenticate identity resolved to: " + r);
		try
		{
			SecurityContext ret = voAuthz.establishSecurityContext(r);
			if (log.isDebugEnabled())
				log.debug("Successfully established security " +
					"context for " + r.prettyString());
			return ret;
		} catch (AuthenticationException e)
		{
			throw new IdUnresolvedException("Wrong credentials (on: " + 
					name + ") for identity: " + r.prettyString());
		} catch (IdentityNotKnownException e)
		{
			throw new IdUnresolvedException("Unknown identity (on: " 
					+ name + "): " + r.prettyString());
		}
	}

}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/idresolver/AbstractResolver.java <==
/*
 * Copyright (c) 2009 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on 2010-01-25
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server.idresolver;

import org.apache.log4j.Logger;

import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.exceptions.AuthenticationException;
import pl.edu.icm.unicore.uvos.api.exceptions.IdentityNotKnownException;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.InvalidValueException;
import pl.edu.icm.unicore.uvos.engine.InternalAuthorization;
import pl.edu.icm.unicore.uvos.engine.SecurityContext;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;

public abstract class AbstractResolver implements IResolver
{
	private static final Logger log = Log.getLogger(UVOSServerProperties.LOG_PFX, AbstractResolver.class);
	
	protected InternalAuthorization voAuthz;

	public AbstractResolver(InternalAuthorization voAuthz)
	{
		this.voAuthz = voAuthz;
	}

	protected SecurityContext authenticate(Identity r, String name) 
		throws IdUnresolvedException, InternalException, InvalidValueException
	{
		if (log.isTraceEnabled())
			log.trace("Trying to authenticate identity resolved to: " + r);
		try
		{
			SecurityContext ret = voAuthz.establishSecurityContext(r);
			if (log.isDebugEnabled())
				log.debug("Successfully established security " +
					"context for " + r.prettyString());
			return ret;
		} catch (AuthenticationException e)
		{
			throw new IdUnresolvedException("Wrong credentials (on: " + 
					name + ") for identity: " + r.prettyString());
		} catch (IdentityNotKnownException e)
		{
			throw new IdUnresolvedException("Unknown identity (on: " 
					+ name + "): " + r.prettyString());
		}
	}

}
